@@ -2,9 +2,11 @@ import numpy as np
 import astropy.coordinates
 from astropy import units as u
 from astropy.time import Time
+import scipy.interpolate
+import os
 
 # All units SI
-mSun = 2e30
+mSun = 1.9891e30
 lSun = 3.826e26
 kpc = 3e19
 Gyr = 3.15e16
@@ -27,6 +29,14 @@ mas2rad = 4.8481368110954e-9
 # mas - conversion factor which multiplies a value in milli-arcseconds to give degrees
 mas = mas2rad*180/np.pi
 
+# loads data needed to find astrometric error as functon of magnitude
+local_dir = os.path.dirname(__file__) #<-- absolute dir the script is in
+rel_path = 'data/scatteral_edr3.csv'
+abs_file_path = os.path.join(local_dir, rel_path)
+sigma_al_data = np.genfromtxt(abs_file_path,skip_header=1,delimiter=',',unpack=True)
+mags=sigma_al_data[0]
+sigma_als=sigma_al_data[1]
+sigma_ast = scipy.interpolate.interp1d(mags, sigma_als, bounds_error=False)
 
 # ----------------
 # -User functions
@@ -90,7 +100,7 @@ def track(ts, ps, comOnly=False, allComponents=False):
     design_phis=np.hstack([90*np.ones_like(ts),np.zeros_like(ts)])
     xij = design_matrix(design_ts,design_phis,ps.RA,ps.Dec, epoch=ps.epoch)
 
-    RAc0=ps.RA*np.cos(np.deg2rad(ps.RA))/mas # RAcos(Dec) in mas
+    RAc0=ps.RA*np.cos(np.deg2rad(ps.Dec))/mas # RAcos(Dec) in mas
     Dec0=ps.Dec/mas # Dec in mas
 
     r = np.array([RAc0, Dec0, ps.pllx, ps.pmRAc, ps.pmDec])
@@ -113,7 +123,7 @@ def track(ts, ps, comOnly=False, allComponents=False):
         d2s = ps.pllx*(py2s*np.cos(ps.vOmega)-px2s*np.sin(ps.vOmega))
         return ras+rls, decs+dls, ras+r1s, decs+d1s, ras+r2s, decs+d2s
 
-def mock_obs(phis, racs, decs, errs=0):
+def mock_obs(phis, racs, decs, err=0):
     """
     Converts positions to comparable observables to real astrometric measurements
     (i.e. 1D psoitions along some scan angle, optionlly with errors added)
@@ -122,11 +132,11 @@ def mock_obs(phis, racs, decs, errs=0):
         - phis,     ndarray - Scanning angles (0 north, 90 east), degrees.
         - racs,     ndarray - RAcosDec at each scan, mas
         - decs,     ndarray - Dec at each scan, mas
-        - errs,     float or ndarray - optional normal distributed error to be added
+        - err,     float or ndarray - optional normal distributed error to be added
     Returns:
         - xs        ndarray - 1D projected displacements
     """
-    xs=racs*np.sin(np.deg2rad(phis)) + decs*np.cos(np.deg2rad(phis)) + errs*np.random.randn(phis.size)
+    xs=racs*np.sin(np.deg2rad(phis)) + decs*np.cos(np.deg2rad(phis)) + err*np.random.randn(phis.size)
     return xs
 
 # ----------------
